/* 
 * This file is part of the Echo2 Effects Extension (hereinafter "EEE").
 * Copyright (C) 2002-2005 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */

// Quirk race condition workaround to touch low level contructs before they are accessed.
Class.create();
new Element.toggle();

EchoEffectsCommand = function() {}
 
/**
 * ServerMessage process() implementation.
 */
EchoEffectsCommand.process = function(messagePartElement) {
    for (var i = 0; i < messagePartElement.childNodes.length; ++i) {
        if (messagePartElement.childNodes[i].nodeType == 1) {
            switch (messagePartElement.childNodes[i].tagName) {
            case "shake":
                EchoEffectsCommand.processShake(messagePartElement.childNodes[i]);
                break;
            case "opacity":
                EchoEffectsCommand.processOpacity(messagePartElement.childNodes[i]);
                break;
            case "scale":
                EchoEffectsCommand.processScale(messagePartElement.childNodes[i]);
                break;
            case "fade":
                EchoEffectsCommand.processFade(messagePartElement.childNodes[i]);
                break;
            case "appear":
                EchoEffectsCommand.processAppear(messagePartElement.childNodes[i]);
                break;
             case "puff":
                EchoEffectsCommand.processPuff(messagePartElement.childNodes[i]);
                break;
             case "blindup":
                EchoEffectsCommand.processBlindup(messagePartElement.childNodes[i]);
                break;
             case "blinddown":
                EchoEffectsCommand.processBlinddown(messagePartElement.childNodes[i]);
                break;
             case "switchoff":
                EchoEffectsCommand.processSwitchoff(messagePartElement.childNodes[i]);
                break;
             case "dropout":
                EchoEffectsCommand.processDropout(messagePartElement.childNodes[i]);
                break;
             case "slideup":
                EchoEffectsCommand.processSlideup(messagePartElement.childNodes[i]);
                break;
             case "slidedown":
                EchoEffectsCommand.processSlidedown(messagePartElement.childNodes[i]);
                break;
             case "pulsate":
                EchoEffectsCommand.processPulsate(messagePartElement.childNodes[i]);
                break;   
             case "squish":
                EchoEffectsCommand.processSquish(messagePartElement.childNodes[i]);
                break;
             case "fold":
                EchoEffectsCommand.processFold(messagePartElement.childNodes[i]);
                break;
             case "grow":
                EchoEffectsCommand.processGrow(messagePartElement.childNodes[i]);
                break;
             case "shrink":
                EchoEffectsCommand.processShrink(messagePartElement.childNodes[i]);
                break;
             case "highlight":
                EchoEffectsCommand.processHighlight(messagePartElement.childNodes[i]);
                break;
            }
        }
    }
};

EchoEffectsCommand.processSlideup = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.SlideUp(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processSlidedown = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.SlideDown(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processPulsate = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Pulsate(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processSquish = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Squish(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processFold = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Fold(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processGrow = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Grow(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processShrink = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Shrink(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processHighlight = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Highlight(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processShake = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    Effect.Shake(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processFade = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Fade(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processAppear = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Appear(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processPuff = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Puff(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processBlindup = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.BlindUp(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processBlinddown = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.BlindDown(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processSwitchoff = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.SwitchOff(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processDropout = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    Effect.DropOut(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processOpacity = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    new Effect.Opacity(componentId, EchoEffectsCommand.getOptionString(effectsElement)); 
};

EchoEffectsCommand.processScale = function(effectsElement) {
    var componentId = effectsElement.getAttribute("component-id");
    var options = "{scaleX: " + 
    			  effectsElement.getAttribute("scaleX") + 
    			  ", scaleY: " + 
    			  effectsElement.getAttribute("scaleY") + 
    			  ", scaleContent: " + 
    			  effectsElement.getAttribute("scale-contents") + 
    			  ", scaleFromCenter: " + 
    			  effectsElement.getAttribute("scale-from-center") + 
    			  ", scaleMode: " + 
    			  effectsElement.getAttribute("scale-mode") + 
    			  ", scaleFrom: " + 
    			  effectsElement.getAttribute("scale-from") + 
    			  ", " + EchoEffectsCommand.getDefaultOptions(effectsElement) + "}";
    var percentage = effectsElement.getAttribute("scale-to");
    new Effect.Scale(componentId,percentage,options); 
};

EchoEffectsCommand.getOptionString = function(effectsElement) {
    return "{" + EchoEffectsCommand.getDefaultOptions(effectsElement) + "}";
}

EchoEffectsCommand.getDefaultOptions = function(effectsElement) {
	var optionString = " duration: " + 
						effectsElement.getAttribute("duration") + 
						", transition: " + 
						effectsElement.getAttribute("transition") + 
						", start: " + 
						effectsElement.getAttribute("start") + 
						", end: " + 
						effectsElement.getAttribute("end") + 
						"";
	return optionString;
}