/* 
 * This file is part of the Echo2 ToolTips Extension (hereinafter "ETTE").
 * Copyright (C) 2002-2005 NextApp, Inc.
 *
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 */
 
EchoToolTip = function(){}
 
EchoToolTip.MessageProcessor = function(){}
 
EchoToolTip.MessageProcessor.process = function(messagePartElement) {
    for (var i = 0; i < messagePartElement.childNodes.length; ++i) {
        if (messagePartElement.childNodes[i].nodeType == 1) {
            switch (messagePartElement.childNodes[i].tagName) {
            case "init":
                EchoToolTip.MessageProcessor.processInit(messagePartElement.childNodes[i]);
                break;
            case "dispose":
                EchoToolTip.MessageProcessor.processDispose(messagePartElement.childNodes[i]);
                break;
            }
        }
    }
};

EchoToolTip.MessageProcessor.processInit = function(initMessageElement) {
		for (var item = initMessageElement.firstChild; item; item = item.nextSibling) {
        	var elementId = item.getAttribute("eid");
        	EchoDomPropertyStore.setPropertyValue(elementId, "tooltip", item.getAttribute("tooltip-id"));
			EchoEventProcessor.addHandler(elementId, "mouseout", "EchoToolTip.hideToolTip");
        	EchoEventProcessor.addHandler(elementId, "mouseover", "EchoToolTip.showToolTip");
        	EchoEventProcessor.addHandler(elementId, "mousemove", "EchoToolTip.updateToolTip");
        }
};

EchoToolTip.MessageProcessor.processDispose = function(disposeMessageElement) {
    for (var item = disposeMessageElement.firstChild; item; item = item.nextSibling) {
        var elementId = item.getAttribute("eid");
     	EchoEventProcessor.removeHandler(elementId, "mouseout");
        EchoEventProcessor.removeHandler(elementId, "mouseover");
        EchoEventProcessor.removeHandler(elementId, "mousemove");
 	}       
};
 
EchoToolTip.updateToolTip = function(event) {
	var elementId = event.registeredTarget.getAttribute("id");
	var id = EchoDomPropertyStore.getPropertyValue(elementId, "tooltip");
	var toolTip = document.getElementById(id);	
	if (toolTip) {
		x = (document.all) ? window.event.x + document.body.scrollLeft : event.pageX;
		y = (document.all) ? window.event.y + document.body.scrollTop  : event.pageY;
		
		var node = toolTip.offsetParent;
        while (node != null) {
			x -= node.offsetLeft
			y -= node.offsetTop
			node = node.offsetParent;
		}
		
		toolTip.style.left = (x + 10) + "px";
		toolTip.style.top = (y + 10) + "px";
	}
};

EchoToolTip.showToolTip = function(event) {
    var elementId = event.registeredTarget.getAttribute("id");
	var id = EchoDomPropertyStore.getPropertyValue(elementId, "tooltip");
	var toolTip = document.getElementById(id);
	if (toolTip) {
		toolTip.style.display = "block"
	}
};

EchoToolTip.hideToolTip = function(event) {
	var elementId = event.registeredTarget.getAttribute("id");
	var id = EchoDomPropertyStore.getPropertyValue(elementId, "tooltip");
	var toolTip = document.getElementById(id);
	if (toolTip) {
		toolTip.style.display = "none";
	}
};